@@ -5,12 +5,11 @@ Simple Axisline3
 
 """
 import matplotlib.pyplot as plt
-from mpl_toolkits.axisartist.axislines import Subplot
+from mpl_toolkits.axisartist.axislines import Axes
 
 fig = plt.figure(figsize=(3, 3))
 
-ax = Subplot(fig, 111)
-fig.add_subplot(ax)
+ax = fig.add_subplot(axes_class=Axes)
 
 ax.axis["right"].set_visible(False)
 ax.axis["top"].set_visible(False)
