@@ -7,7 +7,6 @@ This example shows a how to create a grouped bar chart and how to annotate
 bars with labels.
 """
 
-import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -26,8 +25,7 @@ rects2 = ax.bar(x + width/2, women_means, width, label='Women')
 # Add some text for labels, title and custom x-axis tick labels, etc.
 ax.set_ylabel('Scores')
 ax.set_title('Scores by group and gender')
-ax.set_xticks(x)
-ax.set_xticklabels(labels)
+ax.set_xticks(x, labels)
 ax.legend()
 
 ax.bar_label(rects1, padding=3)
@@ -39,15 +37,10 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods and classes is shown
-# in this example:
-
-matplotlib.axes.Axes.bar
-matplotlib.pyplot.bar
-matplotlib.axes.Axes.bar_label
-matplotlib.pyplot.bar_label
+#    - `matplotlib.axes.Axes.bar` / `matplotlib.pyplot.bar`
+#    - `matplotlib.axes.Axes.bar_label` / `matplotlib.pyplot.bar_label`
